@@ -149,11 +149,17 @@ def get_jobs(**kwargs):
     return get(JOBS_URL, **kwargs)
 
 
-def update_job_status(job_url, status):
-    logger.info(f'Updating job status: f{job_url} ...')
-    job_json = get(job_url)
-    job_json['status'] = status
-    return put(job_url, json=job_json)
+def update_job_status(job, status, attach_log=False):
+    # Update status
+    job['status'] = status
+
+    # Attach logfile if requested
+    if attach_log:
+        files = {'log': open(logger.file_path)}
+        return put(job['url'], data=job, files=files)
+    else:
+        job.pop('log', None)
+        return put(job['url'], json=job)
 
 
 def get_submissions(job_url=None, current_round=None):
